from pyterrier_alpha import validate
from pyterrier_alpha.dataframe_builder import DataFrameBuilder
from pyterrier_alpha import io
from pyterrier_alpha import artifact
from pyterrier_alpha.artifact import Artifact
from pyterrier_alpha.rbo import RBO, rbo
from pyterrier_alpha.transformer_repr import transformer_repr

__version__ = '0.4.1'



import inspect

def transformer_repr(self):
    cls = self.__class__
    init = self.__init__
    signature = inspect.signature(init)
    mode = 'pos'
    args = []
    for p in signature.parameters.values():
        if p.kind not in (inspect.Parameter.POSITIONAL_ONLY, inspect.Parameter.POSITIONAL_OR_KEYWORD):
            mode = 'kwd'
        val = getattr(self, p.name)
        if val != p.default:
            args.append(f'{p.name}={val!r}' if mode == 'kwd' else repr(val))
        else:
            mode = 'kwd' # skip a paramter, force keyword mode
    return cls.__name__ + '(' + ', '.join(args) + ')'
